
#ifndef _ACFG_H
#define _ACFG_H

#include "config.h"
#include "meta.h"

#define ACVERSION "0.4.6"

class hostdata;

namespace acfg
{

extern MYSTD::string cachedir, logdir, confdir, fifopath, user, group, pidfile, 
reportpage, vfilepat, pfilepat, wfilepat, agentname, remoteport, adminauth, bindaddr, port, sUmask;

extern int debug, offlinemode, foreground, verbose, stupidfs, forcemanaged, 
verboselog, extreshhold, exfailabort, tpstandbymax, tpthreadmax, dnscachetime, dlbufsize,
exporigin, logxff, oldupdate, recompbz2, nettimeout, updinterval, forwardsoap;

extern tHttpUrl proxy_info;

bool SetOption(const MYSTD::string &line, bool bQuiet=false);
void ReadConfigDirectory(const char*);

//! Prepare various things resulting from variable combinations, etc.
void PostProcConfig();

// TODO: document me
// throw away the rewritten part of the path, foo/debian/bla.deb -> bla.deb,
// no slash needed with backends...
				
const MYSTD::string * GetRepNameAndPathResidual(const tHttpUrl & in, MYSTD::string & sRetPathResidual);

typedef MYSTD::vector<tHttpUrl> tHostiVec; 
tHostiVec * GetBackendVec(const MYSTD::string * vname);

}

#endif
